@@ -1,6 +1,9 @@
 package Mite::Attribute;
 use Mite::Miteception;
 
+our $AUTHORITY = 'cpan:TOBYINK';
+our $VERSION   = '0.001000';
+
 has class =>
   is            => rw,
   isa           => Object,
@@ -154,7 +157,7 @@ sub clone {
     $args{default} = $self->default
         if !exists $args{default} and $self->has_default;
 
-    return $self->new( %args );
+    return ref($self)->new( %args );
 }
 
 sub is_private {
