@@ -1,6 +1,9 @@
 package Mite::Class;
 use Mite::Miteception;
 
+our $AUTHORITY = 'cpan:TOBYINK';
+our $VERSION   = '0.001000';
+
 use Path::Tiny;
 use mro;
 
@@ -118,6 +121,7 @@ sub chained_attributes {
 sub all_attributes {
     my $self = shift;
 
+    return $self->attributes unless @{ $self->superclasses || [] };
     return $self->chained_attributes($self->linear_parents);
 }
 
