@@ -1,6 +1,9 @@
 package Mite::Compiled;
 use Mite::Miteception;
 
+our $AUTHORITY = 'cpan:TOBYINK';
+our $VERSION   = '0.001000';
+
 use Path::Tiny;
 
 =head1 NAME
