@@ -1,6 +1,9 @@
 package Mite::Config;
 use Mite::Miteception;
 
+our $AUTHORITY = 'cpan:TOBYINK';
+our $VERSION   = '0.001000';
+
 has mite_dir_name =>
   is            => ro,
   isa           => Str,
