@@ -1,6 +1,9 @@
 package Mite::Source;
 use Mite::Miteception;
 
+our $AUTHORITY = 'cpan:TOBYINK';
+our $VERSION   = '0.001000';
+
 =head1 NAME
 
 Mite::Source - Representing the human written .pm file.
@@ -37,7 +40,7 @@ use Mite::Class;
 
 has file =>
   is            => ro,
-  isa           => Path,
+  isa           => Path->no_coercions->plus_coercions(Str, 'Path::Tiny::path($_)'),,
   coerce        => true,
   required      => true;
 
